module.exports={A:{A:{"2":"I F E D A B hB"},B:{"1":"S UB M HB","2":"C O P H J K L"},C:{"2":"0 1 2 3 4 5 6 7 8 9 aB OB G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T gB oB","132":"LB MB NB FB PB QB RB S","1090":"R","1412":"KB","1668":"N IB JB"},D:{"1":"JB KB LB MB NB FB PB QB RB S UB M HB pB rB YB","2":"0 1 2 3 4 5 6 7 8 9 G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N","2114":"IB"},E:{"1":"P iB jB","2":"G V I F E D ZB SB bB cB dB eB","4100":"A B C O TB U x"},F:{"2":"D B C H J K L W X Y Z a b c d e f g h i j k l m n kB lB mB nB U VB PC x","8196":"0 1 2 3 4 5 6 7 8 9 o p q r s t u v w Q y z BB DB EB CB AB T R N"},G:{"1":"8B","2":"E SB qB XB sB tB uB vB","4100":"wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B"},H:{"2":"9B"},I:{"2":"OB G M AC BC CC DC XB EC FC"},J:{"2":"F A"},K:{"2":"A B C Q U VB x"},L:{"16388":"M"},M:{"16388":"N"},N:{"2":"A B"},O:{"2":"GC"},P:{"2":"G HC IC JC KC LC TB MC"},Q:{"2":"NC"},R:{"2":"OC"},S:{"2":"fB"}},B:7,C:"Picture-in-Picture"};
