module.exports={A:{A:{"2":"I F E D A B hB"},B:{"1":"K L S UB M HB","2":"C O P","322":"H J"},C:{"1":"0 1 2 4 5 6 7 8 9 v Q y z WB GB DB EB CB AB T R IB JB KB LB MB NB FB PB QB RB S","2":"aB OB G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j gB oB","194":"k l m n o p q r s t u","513":"3 w BB N"},D:{"1":"0 1 2 3 4 5 6 7 8 9 w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S UB M HB pB rB YB","2":"G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q","4":"r s t u v"},E:{"1":"C O P U x iB jB","2":"G V I F E D A B ZB SB bB cB dB eB TB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 j k l m n o p q r s t u v w Q y z BB DB EB CB AB T R N","2":"D B C H J K L W X Y Z a b c d kB lB mB nB U VB PC x","4":"e f g h i"},G:{"1":"1B 2B 3B 4B 5B 6B 7B 8B","2":"E SB qB XB sB tB uB vB wB xB yB zB 0B"},H:{"2":"9B"},I:{"2":"OB G AC BC CC DC XB EC FC","4":"M"},J:{"2":"F A"},K:{"2":"A B C U VB x","4":"Q"},L:{"1":"M"},M:{"1":"N"},N:{"2":"A B"},O:{"1":"GC"},P:{"1":"G HC IC JC KC LC TB MC"},Q:{"1":"NC"},R:{"4":"OC"},S:{"2":"fB"}},B:4,C:"Service Workers"};
