module.exports={A:{A:{"1":"B","2":"I F E hB","8":"D A"},B:{"1":"C O P H J K L S UB M HB"},C:{"1":"0 1 2 3 4 5 6 7 8 9 P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S","2":"aB OB G V I F E D A B C O gB oB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S UB M HB pB rB YB","2":"G V I F E D A B C O P H J K","33":"L W X Y Z a b c d"},E:{"1":"F E D A B C O P cB dB eB TB U x iB jB","2":"G V ZB SB bB","33":"I"},F:{"1":"0 1 2 3 4 5 6 7 8 9 H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z BB DB EB CB AB T R N","2":"D B C kB lB mB nB U VB PC x"},G:{"1":"E uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B","2":"SB qB XB sB","33":"tB"},H:{"2":"9B"},I:{"1":"M EC FC","2":"OB AC BC CC","8":"G DC XB"},J:{"1":"A","2":"F"},K:{"1":"Q","2":"A B C U VB x"},L:{"1":"M"},M:{"1":"N"},N:{"1":"B","8":"A"},O:{"1":"GC"},P:{"1":"G HC IC JC KC LC TB MC"},Q:{"1":"NC"},R:{"1":"OC"},S:{"1":"fB"}},B:1,C:"Mutation Observer"};
