module.exports={A:{A:{"1":"B","2":"I F E D A hB"},B:{"1":"C O P H J K L","129":"S UB M HB"},C:{"1":"0 1 2 3 4 5 6 7 8 9 aB OB G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S gB oB"},D:{"129":"0 1 2 3 4 5 6 7 8 9 G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S UB M HB pB rB YB"},E:{"257":"G V I F E D A B C O P ZB SB bB cB dB eB TB U x iB jB"},F:{"129":"0 1 2 3 4 5 6 7 8 9 H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z BB DB EB CB AB T R N","513":"D B C kB lB mB nB U VB PC x"},G:{"1026":"E SB qB XB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B"},H:{"1026":"9B"},I:{"1":"OB G AC BC CC DC XB","513":"M EC FC"},J:{"1":"F","1026":"A"},K:{"1026":"A B C Q U VB x"},L:{"1":"M"},M:{"1":"N"},N:{"1026":"A B"},O:{"257":"GC"},P:{"1":"HC IC JC KC LC TB MC","513":"G"},Q:{"129":"NC"},R:{"1":"OC"},S:{"1":"fB"}},B:1,C:"PNG favicons"};
