module.exports={A:{A:{"644":"I F E D hB","772":"A B"},B:{"1":"L S UB M HB","260":"C O P H J K"},C:{"1":"0 1 2 3 4 5 6 7 8 9 G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S gB oB","8":"aB OB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S UB M HB pB rB YB"},E:{"1":"G V I F E D A B C O P ZB SB bB cB dB eB TB U x iB jB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 C H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z BB DB EB CB AB T R N x","8":"D B kB lB mB nB U VB PC"},G:{"2":"E SB qB XB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B"},H:{"2":"9B"},I:{"2":"OB G AC BC CC DC XB EC FC","1025":"M"},J:{"2":"F A"},K:{"1":"x","8":"A B C U VB","1025":"Q"},L:{"1025":"M"},M:{"2":"N"},N:{"1":"A B"},O:{"2":"GC"},P:{"2":"G HC IC JC KC LC TB MC"},Q:{"1":"NC"},R:{"2":"OC"},S:{"2":"fB"}},B:1,C:"Drag and Drop"};
