module.exports={A:{A:{"2":"I F E D A B hB"},B:{"2":"C O P H J K L","513":"S UB M HB"},C:{"1":"R N IB JB KB LB MB NB FB PB QB RB S","2":"aB OB G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q gB oB","322":"0 1 2 3 4 5 6 7 8 9 y z WB BB GB DB EB CB AB T"},D:{"2":"G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o","130":"p q r","513":"0 1 2 3 4 5 6 7 8 9 s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S UB M HB pB rB YB"},E:{"1":"O P iB jB","2":"G V I F E D A B C ZB SB bB cB dB eB TB U x"},F:{"2":"D B C H J K L W X Y Z a b c d e f g h i j k l m n o p q s kB lB mB nB U VB PC x","513":"0 1 2 3 4 5 6 7 8 9 r t u v w Q y z BB DB EB CB AB T R N"},G:{"1":"6B 7B 8B","2":"E SB qB XB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B"},H:{"2":"9B"},I:{"2":"OB G M AC BC CC DC XB EC FC"},J:{"2":"F A"},K:{"2":"A B C Q U VB x"},L:{"2":"M"},M:{"1":"N"},N:{"2":"A B"},O:{"2":"GC"},P:{"2":"G HC IC JC KC LC TB MC"},Q:{"2":"NC"},R:{"2":"OC"},S:{"322":"fB"}},B:6,C:"FIDO U2F API"};
