module.exports={A:{A:{"1":"I F E D A hB","132":"B"},B:{"132":"C O P H J K L","260":"S UB M HB"},C:{"1":"aB OB G V I F E D A B C O P H J K L W X Y Z a b c d e f g gB oB","516":"0 1 2 3 4 5 6 7 8 9 h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S"},D:{"1":"K L W X Y Z a b c d","2":"G V I F E D A B C O P H J","132":"e f g h i j k l m n o p q r","260":"0 1 2 3 4 5 6 7 8 9 s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S UB M HB pB rB YB"},E:{"1":"I bB cB","2":"G V ZB SB","2052":"F E D A B C O P dB eB TB U x iB jB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 D B C H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z BB DB EB CB AB T R N kB lB mB nB U VB PC x"},G:{"2":"SB qB XB","1025":"E sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B"},H:{"1025":"9B"},I:{"1":"OB G M AC BC CC DC XB EC FC"},J:{"1":"F A"},K:{"1":"A B C Q U VB x"},L:{"1":"M"},M:{"1":"N"},N:{"2052":"A B"},O:{"1025":"GC"},P:{"1":"G HC IC JC KC LC TB MC"},Q:{"260":"NC"},R:{"1":"OC"},S:{"516":"fB"}},B:1,C:"autocomplete attribute: on & off values"};
