module.exports={A:{A:{"2":"I F E D A B hB"},B:{"1":"J K L S UB M HB","2":"C O P H"},C:{"1":"2 3 4 5 6 7 8 9 WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S","2":"0 1 aB OB G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z gB oB"},D:{"1":"7 8 9 WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S UB M HB pB rB YB","2":"G V I F E D A B C O P H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u","16":"v w Q","388":"0 1 2 3 4 5 6 y z"},E:{"1":"O P iB jB","2":"G V I F E D A ZB SB bB cB dB eB TB","516":"B C U x"},F:{"1":"0 1 2 3 4 5 6 7 8 9 t u v w Q y z BB DB EB CB AB T R N","2":"D B C H J K L W X Y Z a b c d e f g h i j k l m n o p q r s kB lB mB nB U VB PC x"},G:{"1":"0B 1B 2B 3B 4B 5B 6B 7B 8B","2":"E SB qB XB sB tB uB vB wB xB yB zB"},H:{"2":"9B"},I:{"1":"M","2":"AC BC CC","16":"OB G DC XB EC FC"},J:{"1":"A","2":"F"},K:{"1":"x","16":"A B C U VB","129":"Q"},L:{"1":"M"},M:{"1":"N"},N:{"2":"A B"},O:{"1":"GC"},P:{"1":"HC IC JC KC LC TB MC","129":"G"},Q:{"1":"NC"},R:{"1":"OC"},S:{"2":"fB"}},B:6,C:"FLAC audio format"};
