module.exports={A:{A:{"2":"hB","8":"I F E D A B"},B:{"1":"S UB M HB","8":"C O P H J K L"},C:{"1":"0 1 2 3 4 5 6 7 8 9 c d e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S","2":"aB","8":"OB G V I F E D A B C O P H J K L W X Y Z a b gB oB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z WB BB GB DB EB CB AB T R N IB JB KB LB MB NB FB PB QB RB S UB M HB pB rB YB","2":"G V I F E D A B C O","8":"P H J K L W"},E:{"1":"I F E D A B C O P cB dB eB TB U x iB jB","2":"ZB SB","8":"G V bB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 H J K L W X Y Z a b c d e f g h i j k l m n o p q r s t u v w Q y z BB DB EB CB AB T R N","2":"D B kB lB mB nB","8":"C U VB PC x"},G:{"1":"E tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B","2":"SB","8":"qB XB sB"},H:{"2":"9B"},I:{"1":"M EC FC","8":"OB G AC BC CC DC XB"},J:{"1":"A","8":"F"},K:{"1":"Q","2":"A B","8":"C U VB x"},L:{"1":"M"},M:{"1":"N"},N:{"8":"A B"},O:{"1":"GC"},P:{"1":"G HC IC JC KC LC TB MC"},Q:{"1":"NC"},R:{"1":"OC"},S:{"1":"fB"}},B:1,C:"srcdoc attribute for iframes"};
